summaryrefslogtreecommitdiffstats
path: root/tdehtml/tdehtml_ext.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
commit7427e438358d44c37e3c8b0a9cfbb225ffd60e79 (patch)
treed977f1d23d324f23aadee0ad50acb94d7436ba80 /tdehtml/tdehtml_ext.h
parent72eecb041bf15bf64b748fc062d55f6ec860ac60 (diff)
downloadtdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.tar.gz
tdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.zip
Rename KHTML and kiobuffer
Diffstat (limited to 'tdehtml/tdehtml_ext.h')
-rw-r--r--tdehtml/tdehtml_ext.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/tdehtml/tdehtml_ext.h b/tdehtml/tdehtml_ext.h
index 5a8f00e70..c6db763b9 100644
--- a/tdehtml/tdehtml_ext.h
+++ b/tdehtml/tdehtml_ext.h
@@ -35,16 +35,16 @@
#include <tdeio/global.h>
/**
* This is the BrowserExtension for a KHTMLPart document. Please see the KParts documentation for
* more information about the BrowserExtension.
*/
-class KHTMLPartBrowserExtension : public KParts::BrowserExtension
+class TDEHTMLPartBrowserExtension : public KParts::BrowserExtension
{
Q_OBJECT
- friend class KHTMLPart;
- friend class KHTMLView;
+ friend class TDEHTMLPart;
+ friend class TDEHTMLView;
public:
- KHTMLPartBrowserExtension( KHTMLPart *parent, const char *name = 0L );
+ TDEHTMLPartBrowserExtension( TDEHTMLPart *parent, const char *name = 0L );
virtual int xOffset();
virtual int yOffset();
@@ -84,17 +84,17 @@ signals:
private:
void callExtensionProxyMethod( const char *method );
- KHTMLPart *m_part;
+ TDEHTMLPart *m_part;
TQGuardedPtr<TQWidget> m_editableFormWidget;
TQGuardedPtr<KParts::BrowserExtension> m_extensionProxy;
bool m_connectedToClipboard;
};
-class KHTMLPartBrowserHostExtension : public KParts::BrowserHostExtension
+class TDEHTMLPartBrowserHostExtension : public KParts::BrowserHostExtension
{
public:
- KHTMLPartBrowserHostExtension( KHTMLPart *part );
- virtual ~KHTMLPartBrowserHostExtension();
+ TDEHTMLPartBrowserHostExtension( TDEHTMLPart *part );
+ virtual ~TDEHTMLPartBrowserHostExtension();
virtual TQStringList frameNames() const;
@@ -105,19 +105,19 @@ public:
protected:
virtual void virtual_hook( int id, void* data );
private:
- KHTMLPart *m_part;
+ TDEHTMLPart *m_part;
};
/**
* @internal
* INTERNAL class. *NOT* part of the public API.
*/
-class KHTMLPopupGUIClient : public TQObject, public KXMLGUIClient
+class TDEHTMLPopupGUIClient : public TQObject, public KXMLGUIClient
{
Q_OBJECT
public:
- KHTMLPopupGUIClient( KHTMLPart *tdehtml, const TQString &doc, const KURL &url );
- virtual ~KHTMLPopupGUIClient();
+ TDEHTMLPopupGUIClient( TDEHTMLPart *tdehtml, const TQString &doc, const KURL &url );
+ virtual ~TDEHTMLPopupGUIClient();
static void saveURL( TQWidget *parent, const TQString &caption, const KURL &url,
const TQMap<TQString, TQString> &metaData = TDEIO::MetaData(),
@@ -145,20 +145,20 @@ private slots:
void slotBlockIFrame();
private:
- class KHTMLPopupGUIClientPrivate;
- KHTMLPopupGUIClientPrivate *d;
+ class TDEHTMLPopupGUIClientPrivate;
+ TDEHTMLPopupGUIClientPrivate *d;
};
-class KHTMLZoomFactorAction : public KAction
+class TDEHTMLZoomFactorAction : public KAction
{
Q_OBJECT
public:
//BCI: remove in KDE 4
- KHTMLZoomFactorAction( KHTMLPart *part, bool direction, const TQString &text, const TQString &icon, const TQObject *receiver, const char *slot, TQObject *parent, const char *name );
- KHTMLZoomFactorAction( KHTMLPart *part, bool direction, const TQString &text,
+ TDEHTMLZoomFactorAction( TDEHTMLPart *part, bool direction, const TQString &text, const TQString &icon, const TQObject *receiver, const char *slot, TQObject *parent, const char *name );
+ TDEHTMLZoomFactorAction( TDEHTMLPart *part, bool direction, const TQString &text,
const TQString &icon, const KShortcut& cut, const TQObject *receiver,
const char *slot, TQObject *parent, const char *name );
- virtual ~KHTMLZoomFactorAction();
+ virtual ~TDEHTMLZoomFactorAction();
virtual int plug( TQWidget *widget, int index );
@@ -167,11 +167,11 @@ private slots:
protected slots:
void slotActivated() { KAction::slotActivated(); }
private:
- void init(KHTMLPart *part, bool direction);
+ void init(TDEHTMLPart *part, bool direction);
private:
TQPopupMenu *m_popup;
bool m_direction;
- KHTMLPart *m_part;
+ TDEHTMLPart *m_part;
};
#endif
@@ -35,16 +35,16 @@
#include <tdeio/global.h>
/**
- * This is the BrowserExtension for a KHTMLPart document. Please see the KParts documentation for
+ * This is the BrowserExtension for a TDEHTMLPart document. Please see the KParts documentation for
* more information about the BrowserExtension.
*/